==> lightspark-0.8.5.tar.gz: lightspark-0.8.5/src/scripting/flash/printing/flashprinting.h <==
/**************************************************************************
    Lightspark, a free flash player implementation

    Copyright (C) 2009-2013  Alessandro Pignotti (a.pignotti@sssup.it)

    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU Lesser General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU Lesser General Public License for more details.

    You should have received a copy of the GNU Lesser General Public License
    along with this program.  If not, see <http://www.gnu.org/licenses/>.
**************************************************************************/

#ifndef SCRIPTING_FLASH_PRINTING_FLASHPRINTING_H
#define SCRIPTING_FLASH_PRINTING_FLASHPRINTING_H 1

#include "compat.h"
#include "asobject.h"
#include "scripting/flash/events/flashevents.h"

namespace lightspark
{

class PrintJob: public EventDispatcher
{
public:
	PrintJob(Class_base* c);
	static void sinit(Class_base*);
	ASFUNCTION_ATOM(_constructor);
	ASPROPERTY_GETTER(bool,isSupported);
};

class PrintJobOptions: public ASObject
{
public:
	PrintJobOptions(Class_base* c);
	static void sinit(Class_base*);
	ASFUNCTION_ATOM(_constructor);
};

class PrintJobOrientation: public ASObject
{
public:
	PrintJobOrientation(Class_base* c) : ASObject(c) {}
	static void sinit(Class_base*);
};


}
#endif /* SCRIPTING_FLASH_PRINTING_FLASHPRINTING_H */

==> lightspark-0.9.0.tar.gz: lightspark-0.9.0/src/scripting/flash/printing/flashprinting.h <==
/**************************************************************************
    Lightspark, a free flash player implementation

    Copyright (C) 2009-2013  Alessandro Pignotti (a.pignotti@sssup.it)

    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU Lesser General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU Lesser General Public License for more details.

    You should have received a copy of the GNU Lesser General Public License
    along with this program.  If not, see <http://www.gnu.org/licenses/>.
**************************************************************************/

#ifndef SCRIPTING_FLASH_PRINTING_FLASHPRINTING_H
#define SCRIPTING_FLASH_PRINTING_FLASHPRINTING_H 1

#include "compat.h"
#include "asobject.h"
#include "scripting/flash/events/flashevents.h"

namespace lightspark
{

class PrintJob: public EventDispatcher
{
public:
	PrintJob(ASWorker* wrk,Class_base* c);
	static void sinit(Class_base*);
	ASFUNCTION_ATOM(_constructor);
	ASPROPERTY_GETTER(bool,isSupported);
};

class PrintJobOptions: public ASObject
{
public:
	PrintJobOptions(ASWorker* wrk,Class_base* c);
	static void sinit(Class_base*);
	ASFUNCTION_ATOM(_constructor);
};

class PrintJobOrientation: public ASObject
{
public:
	PrintJobOrientation(ASWorker* wrk,Class_base* c):ASObject(wrk,c) {}
	static void sinit(Class_base*);
};


}
#endif /* SCRIPTING_FLASH_PRINTING_FLASHPRINTING_H */
